tsseg.algorithms.patss package
==============================

Designed for gradual state transitions, learns recurring patterns and assigns labels.

| **Type:** state detection
| **Supervision:** fully unsupervised
| **Scope:** handles gradual transitions

**Implementation:** Adapted from KU Leuven DTAI group. MIT.

**Reference:** Carpentier et al. (2024).

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   tsseg.algorithms.patss.algorithms
   tsseg.algorithms.patss.embedding
   tsseg.algorithms.patss.segmentation

Submodules
----------

tsseg.algorithms.patss.detector module
--------------------------------------

.. automodule:: tsseg.algorithms.patss.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.patss
   :members:
   :show-inheritance:
   :undoc-members:
